@@ -17,13 +17,14 @@
 #' Ehm, W., Gneiting, T., Jordan, A. and Krüger, F. (2016), Of quantiles and expectiles: consistent scoring functions, Choquet representations and forecast rankings. J. R. Stat. Soc. B, 78: 505-562, <doi.org/10.1111/rssb.12154>.
 #' @examples
 #' elementary_score_expectile(1:10, c(1:9, 12), alpha = 0.5, theta = 11)
-#' elementary_score_expectile(1:10, c(1:9, 12), alpha = 0.5, theta = 11, w = rep(1, 10))
-#' elementary_score_quantile(1:10, c(1:9, 12), alpha = 0.5, theta = 11, w = rep(1, 10))
+#' elementary_score_quantile(1:10, c(1:9, 12), alpha = 0.5, theta = 11)
+#' @seealso \code{\link{murphy_diagram}}.
 NULL
 
 #' @rdname elementary_score
 #' @export
-elementary_score_expectile <- function(actual, predicted, w = NULL, alpha = 0.5, theta = 0, ...) {
+elementary_score_expectile <- function(actual, predicted, w = NULL,
+                                       alpha = 0.5, theta = 0, ...) {
   stopifnot(length(alpha) == 1L, alpha >= 0, alpha <= 1,
             length(theta) == 1L,
             length(actual) == length(predicted))
@@ -39,7 +40,8 @@ elementary_score_expectile <- function(actual, predicted, w = NULL, alpha = 0.5,
 
 #' @rdname elementary_score
 #' @export
-elementary_score_quantile <- function(actual, predicted, w = NULL, alpha = 0.5, theta = 0, ...) {
+elementary_score_quantile <- function(actual, predicted, w = NULL,
+                                      alpha = 0.5, theta = 0, ...) {
   stopifnot(length(alpha) == 1L, alpha >= 0, alpha <= 1,
             length(theta) == 1L,
             length(actual) == length(predicted))
