@@ -3,7 +3,9 @@ knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>",
   warning = FALSE,
-  message = FALSE
+  message = FALSE,
+  fig.width = 5.5,
+  fig.height = 4.5
 )
 
 ## ----setup--------------------------------------------------------------------
@@ -39,7 +41,6 @@ deviance_tweedie(y_num, pred_num, tweedie_p = 2)
 deviance_tweedie(y_num, pred_num, tweedie_p = 1.99)
 deviance_tweedie(y_num, pred_num, tweedie_p = 2.01)
 
-
 ## -----------------------------------------------------------------------------
 # The data
 y_cat <- iris[["Species"]] == "setosa"
@@ -52,28 +53,30 @@ AUC(y_cat, pred_cat, w = weights)  # weighted
 logLoss(y_cat, pred_cat)  # Logloss
 deviance_bernoulli(y_cat, pred_cat)  # LogLoss * 2
 
-
 ## -----------------------------------------------------------------------------
 summary(fit_num)$r.squared
 
 # same
 r_squared(y_num, pred_num)
-r_squared(y_num, pred_num, deviance_function = deviance_tweedie, tweedie_p = 0)
-r_squared(y_num, pred_num, deviance_function = deviance_tweedie, tweedie_p = 1.5)
+r_squared(y_num, pred_num, deviance_function = deviance_tweedie, 
+          tweedie_p = 0)
+r_squared(y_num, pred_num, deviance_function = deviance_tweedie, 
+          tweedie_p = 1.5)
 
 # weighted
 r_squared(y_num, pred_num, w = weights)
 r_squared(y_num, pred_num, w = weights, deviance_function = deviance_gamma) 
-r_squared(y_num, pred_num, w = weights, deviance_function = deviance_tweedie, tweedie_p = 2)
-r_squared(y_num, pred_num, deviance_function = deviance_tweedie, tweedie_p = 1.5)
+r_squared(y_num, pred_num, w = weights, deviance_function = deviance_tweedie, 
+          tweedie_p = 2)
+r_squared(y_num, pred_num, deviance_function = deviance_tweedie, 
+          tweedie_p = 1.5)
 
-# respect to own deviance formula
+# respect to 'own' deviance formula
 myTweedie <- function(actual, predicted, w = NULL, ...) {
   deviance_tweedie(actual, predicted, w, tweedie_p = 1.5, ...)
 }
 r_squared(y_num, pred_num, deviance_function = myTweedie)
 
-
 ## -----------------------------------------------------------------------------
 require(dplyr)
 
@@ -110,7 +113,9 @@ iris %>%
   mutate(pred = predict(fit_num, data = .)) %>% 
   group_by(Species) %>% 
   do(performance(., "Sepal.Length", "pred",
-                 metrics = list(rmse = rmse, mae = mae, `R-squared` = r_squared)))
+                 metrics = list(rmse = rmse, 
+                                mae = mae, 
+                                `R-squared` = r_squared)))
 
 # Passing extra argument (Tweedie p)
 iris %>% 
@@ -132,16 +137,21 @@ perf <- performance(ir, actual = "Sepal.Length", predicted = "pred",
 perf$`Tweedie p` <- as.numeric(as.character(perf$`Tweedie p`))
 head(perf)
 
-# Murphy diagram
+# Deviance vs p
 plot(deviance ~ `Tweedie p`, data = perf, type = "s")
 
-# Same for Tweedie-R-squared
+# Same for Pseudo-R-Squared regarding Tweedie deviance
 multi_Tweedie_r2 <- multi_metric(r_squared, deviance_function = deviance_tweedie, 
                                  tweedie_p = c(0, seq(1, 3, by = 0.2)))
 perf <- performance(ir, actual = "Sepal.Length", predicted = "pred", 
                     metrics = multi_Tweedie_r2, key = "Tweedie p", value = "R-squared")
 perf$`Tweedie p` <- as.numeric(as.character(perf$`Tweedie p`))
 
-# Murphy diagram
+# Values vs. p
 plot(`R-squared` ~ `Tweedie p`, data = perf, type = "s")
 
+## -----------------------------------------------------------------------------
+y <- 1:10
+two_models <- cbind(m1 = 1.1 * y, m2 = 1.2 * y)
+murphy_diagram(y, two_models, theta = seq(0.9, 1.3, by = 0.01))
+
